/*
 * TD Langage C - Institut d'Optique - 1A / S5
 * 	Bibliothèque de fonctions / Tableaux 1D
 * 	Auteur : Julien VILLEMEJANE / 2018
 */

 #include "tab1D.h"

/*
 * afficheTabDbl : Affiche dans la console un tableau de double
 * 	ENTREES :
 *		t[] : adresse du tableau à afficher (type double)
 *      dim : dimension du tableau à afficher (entier)
 * 	SORTIE :
 * 		Affichage sur la console
 * 	Auteur : Julien Villemejane / Création : 05/07/2018
 */
void afficheTabDbl(double t[], int dim){
    int i;
    printf("\n");
    for(i = 0; i < dim; i++)
        printf("%.2lf ", t[i]);
    printf("\n");
}

/*
 * sommeTabDbl : Calcule la somme des éléments d'un tableau de double
 * 	ENTREES :
 *		t[] : adresse du tableau à afficher (type double)
 *      dim : dimension du tableau à afficher (entier)
 * 	SORTIE :
 * 		Somme des éléments (double)
 * 	Auteur : Julien Villemejane / Création : 05/07/2018
 */
double sommeTabDbl(double t[], int dim){
    double res;
    int i;
    res = 0;
    for(i = 0; i < dim; i++)
        res = res + t[i];
    return res;
}

/*
 * remplissageTabIntAlea : Remplit aléatoirement un tableau d'entiers 
 * 				entre min et max
 * 	ENTREES :
 *		t[] : adresse du tableau à afficher (type int)
 *      dim : dimension du tableau à afficher (entier)
 *      mini : valeur minimale du tableau (entier)
 *      maxi : valeur maximale du tableau (entier)
 * 	SORTIE :
 * 		Tableau t rempli
 * 	Auteur : Julien Villemejane / Création : 04/09/2018
 */
void remplissageTabIntAlea(int t[], int dim, int mini, int maxi){
	int i;
	srand(time(NULL));
	for(i = 0; i < dim; i++){
		t[i] = rand()%(maxi-mini+1)+mini;
	}
	return;
}

/*
 * afficheTabInt : Affiche dans la console un tableau d'entiers
 * 	ENTREES :
 *		t[] : adresse du tableau à afficher (type int)
 *      dim : dimension du tableau à afficher (entier)
 * 	SORTIE :
 * 		Affichage sur la console
 * 	Auteur : Julien Villemejane / Création : 04/09/2018
 */
void afficheTabInt(int t[], int dim){
    int i;
    printf("\n");
    for(i = 0; i < dim; i++)
        printf("%d ", t[i]);
    printf("\n");
}

/*
 * sommeTabInt : Calcule la somme des éléments d'un tableau d'entiers
 * 	ENTREES :
 *		t[] : adresse du tableau à analyser (type int)
 *      dim : dimension du tableau à analyser (entier)
 * 	SORTIE :
 * 		Somme des éléments (int)
 * 	Auteur : Julien Villemejane / Création : 04/09/2018
 */
int sommeTabInt(int t[], int dim){
    double res;
    int i;
    res = 0;
    for(i = 0; i < dim; i++)
        res = res + t[i];
    return res;
}

/*
 * moyTabInt : Calcule la moyenne des éléments d'un tableau d'entiers
 * 	ENTREES :
 *		t[] : adresse du tableau à analyser (type int)
 *      dim : dimension du tableau à analyser (entier)
 * 	SORTIE :
 * 		Moyenne des éléments (double)
 * 	Auteur : Julien Villemejane / Création : 05/07/2018
 */
double moyTabInt(int t[], int dim){
	int somme = sommeTabInt(t, dim);
	return (double)somme/(double)dim;
}


/*
 * stdDevTabInt : Calcule l'écart-type des éléments d'un tableau d'entiers
 * 	ENTREES :
 *		t[] : adresse du tableau à analyser (type int)
 *      dim : dimension du tableau à analyser (entier)
 * 	SORTIE :
 * 		Ecart-type des éléments (double)
 * 	Auteur : Julien Villemejane / Création : 05/07/2018
 */
double stdDevTabInt(int t[], int dim){
	double moyenne = moyTabInt(t, dim);
	double resultat = 0;
	int i;
	for(i = 0; i < dim; i++){
		resultat += (t[i] - moyenne)*(t[i] - moyenne);
	}
	return sqrt(resultat)/dim;
}

/*
 * minTabInt : Retourne la valeur minimale d'un tableau d'entiers
 *  ENTREES :
 *		t[] : adresse du tableau à analyser (type int)
 *      dim : dimension du tableau à analyser (entier)
 * 	SORTIE :
 * 		valeur minimale du tableau (int)
 * 	Auteur : Julien Villemejane / Création : 05/07/2018
 */
int minTabInt(int t[], int dim){
	int mini, i;
	mini = t[0];
	for(i = 1; i < dim; i++){
		if(t[i] < mini) mini = t[i];
	}
	return mini;
}

/*
 * maxTabInt : Retourne la valeur maximale d'un tableau d'entiers
 *  ENTREES :
 *		t[] : adresse du tableau à analyser (type int)
 *      dim : dimension du tableau à analyser (entier)
 * 	SORTIE :
 * 		valeur maximale du tableau (int)
 * 	Auteur : Julien Villemejane / Création : 05/07/2018
 */
int maxTabInt(int t[], int dim){
	int maxi, i;
	maxi = t[0];
	for(i = 1; i < dim; i++){
		if(t[i] > maxi) maxi = t[i];
	}
	return maxi;
}
